"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = __importStar(require("react"));
const react_redux_1 = require("react-redux");
const core_1 = require("@nteract/core");
const immutable_1 = require("immutable");
const manager_1 = __importDefault(require("./manager"));
const widget_comms_1 = require("./manager/widget-comms");
/**
 * The WidgetDisplay takes a model_id, which is returned by the
 * display_data payload that is returned from the execution of a
 * cell containing an ipywidget. This model_id is used to retrieve
 * the initial model for the widget from the comms state in the
 * core state model.
 */
class WidgetDisplay extends React.Component {
    constructor(props) {
        super(props);
        this.state = { model: undefined };
    }
    async componentDidMount() {
        const { modelById, data: { model_id } } = this.props;
        const model = await modelById(model_id);
        this.setState({ model });
    }
    render() {
        const { model } = this.state;
        if (model) {
            return (React.createElement(manager_1.default, { model: model, model_id: this.props.data.model_id, id: this.props.id, contentRef: this.props.contentRef, modelById: this.props.modelById, kernel: this.props.kernel }));
        }
        else {
            return null;
        }
    }
}
exports.WidgetDisplay = WidgetDisplay;
WidgetDisplay.MIMETYPE = "application/vnd.jupyter.widget-view+json";
const mapStateToProps = (state, props) => {
    let currentKernel = core_1.selectors.currentKernel(state);
    return {
        modelById: async (model_id) => {
            let model = core_1.selectors.modelById(state, { commId: model_id });
            //if we can't find the model, request the state from the kernel
            if (!model && currentKernel) {
                let request_state_response = await widget_comms_1.request_state(currentKernel, model_id);
                model = immutable_1.fromJS(request_state_response.content.data);
            }
            return model;
        },
        kernel: currentKernel
    };
};
exports.default = react_redux_1.connect(mapStateToProps, null)(WidgetDisplay);
