"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const React = __importStar(require("react"));
const widget_manager_1 = require("./widget-manager");
const backbone_wrapper_1 = __importDefault(require("../renderer/backbone-wrapper"));
const react_redux_1 = require("react-redux");
const core_1 = require("@nteract/core");
/**
 * This component is is a wrapper component that initializes a
 * WidgetManager singleton and passes a model reference to the
 * BackboneModelWrapper. It's doing most of the heavy lifting with
 * respect to bridging the kernels comms that the WidgetManager provides,
 * our client-side state model, and the view.
 */
class Manager extends React.Component {
    constructor(props) {
        super(props);
        this.widgetContainerRef = React.createRef();
    }
    /**
     * Because the iPyWidgets keeps track of the widgets it creates as a
     * member variable, the WidgetManager needs to be treated like a singleton.
     * However, we still need to be constantly updating the singleton with the most up
     * to date modelById function, otherwise it will be searching a stale state for a
     * model
     */
    getManager() {
        if (Manager.manager === undefined) {
            Manager.manager = new widget_manager_1.WidgetManager(this.props.kernel, this.props.modelById, this.props.actions);
        }
        else {
            Manager.manager.update(this.props.kernel, this.props.modelById, this.props.actions);
        }
        return Manager.manager;
    }
    render() {
        return (React.createElement(React.Fragment, null,
            React.createElement(backbone_wrapper_1.default, { model: this.props.model.get("state"), manager: this.getManager(), model_id: this.props.model_id, widgetContainerRef: this.widgetContainerRef })));
    }
}
exports.Manager = Manager;
const mapDispatchToProps = (dispatch, props) => {
    return {
        actions: {
            appendOutput: (output) => dispatch(core_1.actions.appendOutput({
                id: props.id,
                contentRef: props.contentRef,
                output
            })),
            clearOutput: () => dispatch(core_1.actions.clearOutputs({
                id: props.id,
                contentRef: props.contentRef
            })),
            updateCellStatus: (status) => dispatch(core_1.actions.updateCellStatus({
                id: props.id,
                contentRef: props.contentRef,
                status
            })),
            promptInputRequest: (prompt, password) => dispatch(core_1.actions.promptInputRequest({
                id: props.id,
                contentRef: props.contentRef,
                prompt,
                password
            }))
        }
    };
};
exports.default = react_redux_1.connect(null, mapDispatchToProps)(Manager);
